@@ -3,5 +3,8 @@
 __author__ = """Geocube Contributors"""
 __email__ = "alansnow21@gmail.com"
 
+import importlib.metadata
+
 from geocube._show_versions import show_versions  # noqa
-from geocube._version import __version__  # noqa
+
+__version__ = importlib.metadata.version(__package__)
