@@ -1,17 +1,23 @@
 """
 This module contains tools for rasterizing vector data.
 """
-from typing import Optional
+from typing import Optional, Union
 
 import geopandas
 import numpy
 import odc.geo.geobox
 import pandas
+import rasterio
 import rasterio.features
 from numpy.typing import NDArray
+from packaging import version
 from rasterio.enums import MergeAlg
 from scipy.interpolate import Rbf, griddata
 
+_INT8_SUPPORTED = version.parse(rasterio.__gdal_version__) >= version.parse(
+    "3.7.0"
+) and version.parse(rasterio.__version__) >= version.parse("1.3.7")
+
 
 def _is_numeric(data_values: NDArray) -> bool:
     """
@@ -44,12 +50,9 @@ def _minimize_dtype(dtype: numpy.dtype, fill: float) -> numpy.dtype:
     Attempt to convert to float32 if fill is NaN and dtype is integer.
     """
     if numpy.issubdtype(dtype, numpy.integer):
-        if dtype.name == "int8":
-            # GDAL/rasterio doesn't support int8
+        if not _INT8_SUPPORTED and dtype.name == "int8":
+            # GDAL<3.7/rasterio<1.3.7 doesn't support int8
             dtype = numpy.dtype("int16")
-        if dtype.name == "int64":
-            # GDAL/rasterio doesn't support int64
-            dtype = numpy.dtype("float64")
         if numpy.isnan(fill):
             dtype = (
                 numpy.dtype("float64") if dtype.itemsize > 2 else numpy.dtype("float32")  # type: ignore
@@ -62,7 +65,7 @@ def _minimize_dtype(dtype: numpy.dtype, fill: float) -> numpy.dtype:
 
 def rasterize_image(
     geometry_array: geopandas.GeoSeries,
-    data_values: NDArray,
+    data_values: Union[NDArray, pandas.arrays.IntegerArray],
     geobox: odc.geo.geobox.GeoBox,
     fill: float,
     merge_alg: MergeAlg = MergeAlg.replace,
@@ -77,7 +80,7 @@ def rasterize_image(
     -----------
     geometry_array: geopandas.GeoSeries
         A geometry array of points.
-    data_values: list
+    data_values: Union[NDArray, pandas.arrays.IntegerArray]
         Data values associated with the list of geojson shapes
     geobox: :obj:`odc.geo.geobox.GeoBox`
         Transform of the resulting image.
@@ -107,6 +110,12 @@ def rasterize_image(
         # only numbers can be rasterized
         return None
 
+    if isinstance(data_values, pandas.arrays.IntegerArray):
+        data_values = data_values.to_numpy(
+            dtype=_minimize_dtype(data_values.dtype.numpy_dtype, fill),
+            na_value=fill,
+        )
+
     if filter_nan:
         data_values, geometry_array = _remove_missing_data(data_values, geometry_array)
 
